/*
 *  The Syncro Soft SRL License
 *
 *
 *  Copyright (c) 1998-2007 Syncro Soft SRL, Romania.  All rights
 *  reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistribution of source or in binary form is allowed only with
 *  the prior written permission of Syncro Soft SRL.
 *
 *  2. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in
 *  the documentation and/or other materials provided with the
 *  distribution.
 *
 *  3. The end-user documentation included with the redistribution,
 *  if any, must include the following acknowledgment:
 *  "This product includes software developed by the
 *  Syncro Soft SRL (http://www.sync.ro/)."
 *  Alternately, this acknowledgment may appear in the software itself,
 *  if and wherever such third-party acknowledgments normally appear.
 *
 *  4. The names "Oxygen" and "Syncro Soft SRL" must
 *  not be used to endorse or promote products derived from this
 *  software without prior written permission. For written
 *  permission, please contact support@oxygenxml.com.
 *
 *  5. Products derived from this software may not be called "Oxygen",
 *  nor may "Oxygen" appear in their name, without prior written
 *  permission of the Syncro Soft SRL.
 *
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNCRO SOFT SRL OR
 *  ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package ro.sync.diff.api;

import ro.sync.exml.editor.ContentTypes;

/**
 * Content types for the documents used in the diff process.
 */
public interface DiffContentTypes {

  /**
   * Content type for XML documents.
   */
  public static final String XML_CONTENT_TYPE = ContentTypes.XML_CONTENT_TYPE;

  /**
   * Content type for PHP documents.
   */
  public static final String PHP_CONTENT_TYPE = ContentTypes.PHP_CONTENT_TYPE;

  /**
   * Content type for DTD documents.
   */
  public static final String DTD_CONTENT_TYPE = ContentTypes.DTD_CONTENT_TYPE;

  /**
   * Content type for text documents.
   */
  public static final String PLAIN_TEXT_CONTENT_TYPE = ContentTypes.PLAIN_TEXT_CONTENT_TYPE;

  /**
   * Content type for CSS documents.
   */
  public static final String CSS_CONTENT_TYPE = ContentTypes.CSS_CONTENT_TYPE;

  /**
   * Content type for Java documents.
   */
  public static final String JAVA_CONTENT_TYPE = ContentTypes.JAVA_CONTENT_TYPE;

  /**
   * Content type for JavaScript documents.
   */
  public static final String JAVASCRIPT_CONTENT_TYPE = ContentTypes.JAVASCRIPT_CONTENT_TYPE;
  
  /**
   * Content type for JSon documents.
   */
  public static final String JSON_CONTENT_TYPE = ContentTypes.JSON_CONTENT_TYPE;

  /**
   * Content type for C documents.
   */
  public static final String C_CONTENT_TYPE = ContentTypes.C_CONTENT_TYPE;

  /**
   * Content type for C++ documents.
   */
  public static final String CPLUSPLUS_CONTENT_TYPE = ContentTypes.CPLUSPLUS_CONTENT_TYPE;

  /**
   * Content type for batch documents.
   */
  public static final String BATCH_CONTENT_TYPE = ContentTypes.BATCH_CONTENT_TYPE;

  /**
   * Content type for shell documents.
   */
  public static final String SHELL_CONTENT_TYPE = ContentTypes.SHELL_CONTENT_TYPE;

  /**
   * Content type for properties documents.
   */
  public static final String PROPERTIES_CONTENT_TYPE = ContentTypes.PROPERTIES_CONTENT_TYPE;

  /**
   * Content type for SQL documents.
   */
  public static final String SQL_CONTENT_TYPE = ContentTypes.SQL_CONTENT_TYPE;

  /**
   * Content type for PERL documents.
   */
  public static final String PERL_CONTENT_TYPE = ContentTypes.PERL_CONTENT_TYPE;

  /**
   * Content type for RNC documents.
   */
  public static final String RNC_CONTENT_TYPE = ContentTypes.RNC_CONTENT_TYPE;

  /**
   * Content type for XQUERY documents.
   */
  public static final String XQUERY_CONTENT_TYPE = ContentTypes.XQUERY_CONTENT_TYPE;

  /**
   * Content type for PYTHON documents.
   */
  public static final String PYTHON_CONTENT_TYPE = ContentTypes.PYTHON_CONTENT_TYPE;
}